@@ -5,12 +5,12 @@ if [ ! -z "$1" ]
 then
     PREF_VER=$1.$2
 else
-    PREF_VER=3.10
+    PREF_VER=3.13
 fi
 
 export PYCXX_VER=7.1.9
 
-for PY_VER in ${PREF_VER} 3.10 3.9
+for PY_VER in ${PREF_VER} 3.13 3.12 3.10 3.9
 do
     # used in pick python to use in Builder driver makefile
     export PYTHON=$( which python${PY_VER} )
