@@ -97,7 +97,7 @@ class Options:
             option_parts = option.split( '=', 1 )
             option_name = option_parts[0]
             if option_name not in self.all_options_info:
-                print( 'Error: Unknown option %s' % option )
+                print( 'Error: Unknown option %r' % (option,) )
                 return False
 
             repeat_count, value = self.all_options_info[ option_name ]
@@ -1038,8 +1038,12 @@ class MacOsxCompilerGCC(CompilerGCC):
         self._addVar( 'CCC',            'g++ %s -mmacosx-version-min=%s' % (arch_options, self.macosx_deployment_target) )
         self._addVar( 'CC',             'gcc %s -mmacosx-version-min=%s' % (arch_options, self.macosx_deployment_target) )
 
-        self._find_paths_pycxx_dir = [
-                        '../Import/pycxx-%d.%d.%d' % min_pycxx_version,
+        try:
+            pycxx_import = ["../Import/%s" % (t,) for t in os.listdir("../Import") if t.startswith("pycxx")]
+        except FileNotFoundError:
+            pycxx_import = []
+
+        self._find_paths_pycxx_dir = pycxx_import + [
                         sysconfig.get_path('include') # typical Linux
                         ]
 
@@ -1059,31 +1063,41 @@ class MacOsxCompilerGCC(CompilerGCC):
 
         else:
             self._find_paths_svn_inc = [
+                            '/opt/homebrew/include/subversion-1',   # Darwin - homebrew ARM
                             '/opt/local/include/subversion-1',      # Darwin - darwin ports
                             '/sw/include/subversion-1',             # Darwin - Fink
                             '/usr/include/subversion-1',            # typical Linux
                             '/usr/local/include/subversion-1',      # typical *BSD
                             ]
             self._find_paths_svn_bin = [
-                            '/opt/local/bin',                        # Darwin - darwin ports
-                            '/sw/bin',                               # Darwin - Fink
-                            '/usr/bin',                              # typical Linux
-                            '/usr/local/bin',                        # typical *BSD
+                            '/opt/homebrew/bin',                    # Darwin - homebrew ARM
+                            '/opt/local/bin',                       # Darwin - darwin ports
+                            '/sw/bin',                              # Darwin - Fink
+                            '/usr/bin',                             # typical Linux
+                            '/usr/local/bin',                       # typical *BSD
                             ]
             self._find_paths_svn_lib = [
+                            '/opt/homebrew/lib',                    # Darwin - homebrew ARM
                             '/opt/local/lib',                       # Darwin - darwin ports
                             '/sw/lib',                              # Darwin - Fink
                             '/usr/lib',                             # typical Linux
                             '/usr/local/lib',                       # typical *BSD
                             ]
             self._find_paths_apr_inc = [
+                            '/opt/homebrew/opt/apr/include/apr-1',  # Darwin - homebrew ARM
+                            '/usr/local/opt/apr/include/apr-1',     # Darwin - homebrew x86_64
                             '/opt/local/include/apr-1',             # Darwin - darwin ports
                             '/sw/include/apr-1',                    # Darwin - fink
                             '/usr/include/apr-1',                   # typical Linux
                             '/usr/local/apr/include/apr-1',         # Mac OS X www.metissian.com
                             ]
-            self._find_paths_apr_util_inc = self._find_paths_apr_inc
+            self._find_paths_apr_util_inc = self._find_paths_apr_inc + [
+                '/opt/homebrew/opt/apr-util/include/apr-1',         # Darwin - homebrew ARM
+                '/usr/local/opt/apr-util/include/apr-1',            # Darwin - homebrew x86_64
+            ]
             self._find_paths_apr_lib = [
+                            '/opt/homebrew/opt/apr/lib',            # Darwin - homebrew ARM
+                            '/usr/local/opt/apr/lib',               # Darwin - homebrew x86_64
                             '/opt/local/lib',                       # Darwin - darwin ports
                             '/sw/lib',                              # Darwin - fink
                             '/usr/lib64',                           # typical 64bit Linux
@@ -1115,18 +1129,22 @@ class MacOsxCompilerGCC(CompilerGCC):
         # pointing to the root of the virtualenv. That root will *not* contain
         # a Python directory, as needed by PYTHON_FRAMEWORK below.
         #
-        # Instead, we use sys.real_prefix, which is added when in a virtualenv.
+        # Instead, we use sys.base_prefix, which is added when in a virtualenv.
         # This will point to the Python framework that the virtualenv is based
         # upon, which does contain the Python directory. It's equivalent to
         # sys.exec_prefix outside of a virtualenv.
-        python_prefix = getattr( sys, 'real_prefix', sys.exec_prefix )
+        python_prefix = getattr( sys, 'base_prefix', sys.exec_prefix )
+        # On Mac, the OS provided framework is called Python3.
+        framework_bin = sysconfig.get_config_var( 'PYTHONFRAMEWORK' )
+        if framework_bin is None:
+            framework_bin = 'Python'
 
         self._pysvnModuleSetup()
         self._addVar( 'PYSVN_MODULE_BASENAME', self.pysvn_module_name )
 
         self._addVar( 'PYTHON_VERSION',     '%d.%d' % (sys.version_info[0], sys.version_info[1]) )
         self._addVar( 'PYTHON_DIR',         sys.exec_prefix )
-        self._addVar( 'PYTHON_FRAMEWORK',   os.path.join( python_prefix, 'Python' ) )
+        self._addVar( 'PYTHON_FRAMEWORK',   os.path.join( python_prefix, framework_bin ) )
         self._addVar( 'PYTHON_INC',         sysconfig.get_path('include') )
 
         py_cflags_list = [
